@@ -2,7 +2,8 @@ from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 
 from apiautomata.routes import echo, home, missing, proxy
-from apiautomata.routes.exchange import instrument_exchange
+from apiautomata.routes.exchange import instrument_exchange, exchange_rate
+from apiautomata.routes.process import process_enablement, process_status
 from apiautomata.routes.transform import exchange_transform
 
 app = FastAPI()
@@ -13,6 +14,9 @@ app.include_router(proxy.router)
 app.include_router(missing.router)
 app.include_router(instrument_exchange.router)
 app.include_router(exchange_transform.router)
+app.include_router(exchange_rate.router)
+app.include_router(process_enablement.router)
+app.include_router(process_status.router)
 
 origins = ['*']
 
