@@ -1,9 +1,12 @@
 import logging
 
 import uvicorn
+from exchangerepo.repository.ExchangeRateRepository import ExchangeRateRepository
 from exchangerepo.repository.InstrumentExchangeRepository import InstrumentExchangeRepository
 from exchangetransformrepo.repository.ExchangeTransformRepository import ExchangeTransformRepository
 from missingrepo.repository.MissingRepository import MissingRepository
+from processrepo.repository.ProcessRepository import ProcessRepository
+from processrepo.repository.ProcessRunProfileRepository import ProcessRunProfileRepository
 
 from apiautomata.holder.ItemHolder import ItemHolder
 
@@ -24,6 +27,9 @@ class AutomataAPIServer:
         item_holder.add_entity(MissingRepository(self.options))
         item_holder.add_entity(InstrumentExchangeRepository(self.options))
         item_holder.add_entity(ExchangeTransformRepository(self.options))
+        item_holder.add_entity(ExchangeRateRepository(self.options))
+        item_holder.add_entity(ProcessRunProfileRepository(self.options))
+        item_holder.add_entity(ProcessRepository(self.options))
 
     def run(self):
         self.log.info('Running')
